package ogg

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module OggSource

* Functions for manipulating ogg streams files using libogg. * *

  • author Samuel Mimram, Romain Beauxis
Sourceexception Not_enough_data
Sourceexception Bad_data
Sourceexception Out_of_sync
Sourceexception End_of_stream
Sourceexception Internal_error
Sourcemodule Page : sig ... end

* The page struct encapsulates the data for an Ogg page. * * Ogg pages are the fundamental unit of framing and interleave in an ogg * bitstream. They are made up of packet segments of 255 bytes each. There can * be as many as 255 packet segments per page, for a maximum page size of a * little under 64 kB. This is not a practical limitation as the segments can be * joined across page boundaries allowing packets of arbitrary size. In practice * pages are usually around 4 kB.

Sourcemodule Sync : sig ... end
Sourcemodule Stream : sig ... end
Sourcemodule Skeleton : sig ... end